config.PchipInterpolator2D
==========================

.. currentmodule:: config

.. autoclass:: PchipInterpolator2D

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~PchipInterpolator2D.__init__
      ~PchipInterpolator2D.get_val
   
   

   
   
   